==> MousikoFidi-0.20.tar.gz: MousikoFidi-0.20/README.md <==
# MousikóFídi

Arch Linux: [![builds.sr.ht status](https://builds.sr.ht/~hristoast/mousikofidi/archlinux.yml.svg)](https://builds.sr.ht/~hristoast/mousikofidi/archlinux.yml?)
Debian: [![builds.sr.ht status](https://builds.sr.ht/~hristoast/mousikofidi/debian.yml.svg)](https://builds.sr.ht/~hristoast/mousikofidi/debian.yml?)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

MousikóFídi: Your Music Cloud

MousikóFídi is a web application for streaming audio and video files from your personal collection.  It aims to be easy to install and use, with a minimal amount of dependencies.

Logo by **[ogenfald](https://fillmyan.us/)**

**[Demo](https://mousikofidi.info/)** | **[IRC](https://kiwiirc.com/client/irc.freenode.org/?nick=fidi|?#mousikofidi)** | **[Wiki](https://man.sr.ht/~hristoast/mousikofidi/)** | **[Known Issues](https://todo.sr.ht/~hristoast/mousikofidi?search=label:%22Bug%22%20status%3Aopen)** | **[Submit Issue](https://todo.sr.ht/~hristoast/mousikofidi)** | **[Planned Features](https://todo.sr.ht/~hristoast/mousikofidi?search=label:%22Enhancement%22%20status%3Aopen)** | **[PyPI](https://pypi.org/project/MousikoFidi/)**

## Install And Configure

See [the setup guide on the project wiki](https://man.sr.ht/~hristoast/mousikofidi/setup.md).

## Using MousikóFídi

See [the user guide on the project wiki](https://man.sr.ht/~hristoast/mousikofidi/user_guide.md).

## Developing MousikóFídi

See [the developer setup guide on the project wiki](https://man.sr.ht/~hristoast/mousikofidi/devel.md).

## Project Goals

* Maintain simple installation, setup, and usage processes.
* Require minimal dependencies.
* Use only vanilla javascript.
* A responsive user interface that eliminates the need for any "app".

==> MousikoFidi-0.21.tar.gz: MousikoFidi-0.21/README.md <==
# MousikóFídi

Arch Linux: [![builds.sr.ht status](https://builds.sr.ht/~hristoast/mousikofidi/archlinux.yml.svg)](https://builds.sr.ht/~hristoast/mousikofidi/archlinux.yml?)
Debian: [![builds.sr.ht status](https://builds.sr.ht/~hristoast/mousikofidi/debian.yml.svg)](https://builds.sr.ht/~hristoast/mousikofidi/debian.yml?)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

MousikóFídi: Your Music Cloud

MousikóFídi is a web application for streaming audio and video files from your personal collection.  It aims to be easy to install and use, with a minimal amount of dependencies.

Logo by **[ogenfald](https://fillmyan.us/)**

**[Demo](https://demo.mousikofidi.info/)** | **[IRC](https://kiwiirc.com/client/irc.freenode.org/?nick=fidi|?#mousikofidi)** | **[Wiki](https://man.sr.ht/~hristoast/mousikofidi/)** | **[Known Issues](https://todo.sr.ht/~hristoast/mousikofidi?search=label:%22Bug%22%20status%3Aopen)** | **[Submit Issue](https://todo.sr.ht/~hristoast/mousikofidi)** | **[Planned Features](https://todo.sr.ht/~hristoast/mousikofidi?search=label:%22Enhancement%22%20status%3Aopen)** | **[PyPI](https://pypi.org/project/MousikoFidi/)**

## Install And Configure

See [the setup guide on the project wiki](https://man.sr.ht/~hristoast/mousikofidi/setup.md).

## Using MousikóFídi

See [the user guide on the project wiki](https://man.sr.ht/~hristoast/mousikofidi/user_guide.md).

## Developing MousikóFídi

See [the developer setup guide on the project wiki](https://man.sr.ht/~hristoast/mousikofidi/devel.md).

## Project Goals

* Maintain simple installation, setup, and usage processes.
* Require minimal dependencies.
* Use only vanilla javascript.
* A responsive user interface that eliminates the need for any "app".
